@@ -51,7 +51,7 @@
 #include <kstandardaction.h>
 
 #include <QDBusConnection>
-KEBApp *KEBApp::s_topLevel = 0;
+KEBApp *KEBApp::s_topLevel = nullptr;
 
 KEBApp::KEBApp(
     const QString &bookmarksFile, bool readonly,
@@ -78,8 +78,8 @@ KEBApp::KEBApp(
     else
         createGUI(QStringLiteral("keditbookmarks-genui.rc"));
 
-    connect(qApp->clipboard(), SIGNAL(dataChanged()),
-                               SLOT(slotClipboardDataChanged()));
+    connect(qApp->clipboard(), &QClipboard::dataChanged,
+                               this, &KEBApp::slotClipboardDataChanged);
 
     m_canPaste = false;
 
@@ -89,14 +89,14 @@ KEBApp::KEBApp(
     mBookmarkListView->loadColumnSetting();
     mBookmarkListView->loadFoldedState();
 
-    KViewSearchLineWidget *searchline = new KViewSearchLineWidget(mBookmarkListView);
+    KViewSearchLineWidget *searchline = new KViewSearchLineWidget(mBookmarkListView, this);
 
-    mBookmarkFolderView = new BookmarkFolderView(mBookmarkListView);
+    mBookmarkFolderView = new BookmarkFolderView(mBookmarkListView, this);
     mBookmarkFolderView->expandAll();
 
     QWidget * rightSide = new QWidget;
     QVBoxLayout *listLayout = new QVBoxLayout(rightSide);
-    listLayout->setMargin(0);
+    listLayout->setContentsMargins(0, 0, 0, 0);
     rightSide->setLayout(listLayout);
     listLayout->addWidget(searchline);
     listLayout->addWidget(mBookmarkListView);
@@ -116,11 +116,11 @@ KEBApp::KEBApp(
     slotClipboardDataChanged();
     setAutoSaveSettings();
 
-    connect(mBookmarkListView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(selectionChanged()));
+    connect(mBookmarkListView->selectionModel(), &QItemSelectionModel::selectionChanged,
+            this, &KEBApp::selectionChanged);
 
-    connect(mBookmarkFolderView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(selectionChanged()));
+    connect(mBookmarkFolderView->selectionModel(), &QItemSelectionModel::selectionChanged,
+            this, &KEBApp::selectionChanged);
 
     setCancelFavIconUpdatesEnabled(false);
     setCancelTestsEnabled(false);
@@ -362,7 +362,7 @@ KBookmark::List KEBApp::selectedBookmarks() const
 	  if(bk.address() != GlobalBookmarkManager::self()->root().address())
               bookmarks.push_back( bk );
       }
-      qSort(bookmarks.begin(), bookmarks.end(), lessBookmark);
+      std::sort(bookmarks.begin(), bookmarks.end(), lessBookmark);
     } else {
         bookmarks.push_back(firstSelected());
     }
@@ -408,7 +408,7 @@ KEBApp::~KEBApp() {
     // Save again, just in case the user expanded/collapsed folders (#131127)
     GlobalBookmarkManager::self()->notifyManagers();
 
-    s_topLevel = 0;
+    s_topLevel = nullptr;
     delete m_cmdHistory;
     delete m_actionsImpl;
     delete mBookmarkListView;
